@@ -166,19 +166,19 @@ class ModelParser:
 
             args_str = str(args)
             args_str_list = []
-            for i in range(0, len(args_str), 20):
-                end_idx = i + 20
-                args_str_list.append(args_str[i:end_idx])
+            for j in range(0, len(args_str), 20):
+                end_idx = j + 20
+                args_str_list.append(args_str[j:end_idx])
             args_str = args_str_list[0]
             log = (
                 f"{i:3d} | {str(idx):>10} | {repeat:3d} |"
                 f" {module.n_params:8,d} | {module.type:>15} | {args_str:>20} |"
                 f" {module_generator.in_channel:>10} | {module_generator.out_channel:>11} |"
             )
-            for i in range(1, len(args_str_list)):
+            for j in range(1, len(args_str_list)):
                 log += (
                     f"\n{'':>3} | {'':>10} | {'':>3} |"
-                    f" {'':>8} | {'':>15} | {args_str_list[i]:>20} |"
+                    f" {'':>8} | {'':>15} | {args_str_list[j]:>20} |"
                     f" {'':>10} | {'':>11} |"
                 )
 
@@ -211,6 +211,11 @@ class ModelParser:
         for i, (idx, repeat, module, args) in enumerate(model_cfg):  # type: ignore
             if i >= len(self.backbone_cfg):
                 GeneratorAbstract.CHANNEL_DIVISOR = 1
+                width_multiply = 1.0
+                depth_multiply = 1.0
+            else:
+                width_multiply = float(self.width_multiply)  # type: ignore
+                depth_multiply = float(self.depth_multiply)  # type: ignore
 
             module_generator = ModuleGenerator(
                 module, custom_module_paths=self.custom_module_paths
@@ -218,11 +223,9 @@ class ModelParser:
                 *args,
                 from_idx=idx,
                 in_channels=tuple(in_channels) if i > 0 else (self.in_channel,),  # type: ignore
-                width_multiply=self.width_multiply,
-            )
-            repeat = (
-                max(round(repeat * self.depth_multiply), 1) if repeat > 1 else repeat
+                width_multiply=width_multiply,
             )
+            repeat = max(round(repeat * depth_multiply), 1) if repeat > 1 else repeat
 
             if isinstance(module_generator, FlattenGenerator):
                 if self.input_size is not None:
